Crate pdf_extract
source · [−]Structs
Enums
Traits
Functions
Extract the text from a pdf at path and return a String with the results
Parse a given document and output it to output
Extract the text from a pdf at path and return a String with the results
Parse a given document and output it to output